@@ -12,7 +12,7 @@ from xlsx_lib.domain.distribution.data_block import DataBlock
 from xlsx_lib.domain.distribution.distribution_image import DistributionImage
 from xlsx_lib.domain.distribution.distribution_cell_value_types import DistributionCellValueType
 from xlsx_lib.domain.distribution.distribution_data import DistributionData
-from xlsx_lib.domain.distribution.new_distribution_image import NewDistributionImage
+from xlsx_lib.domain.distribution.new_distribution_image import NewImage
 from xlsx_lib.domain.xlsx_elements.exceptions.continue_exception import ContinueException
 from xlsx_lib.domain.xlsx_elements.exceptions.sheet_end_exception import SheetEndException
 from xlsx_lib.domain.xlsx_elements.sheet import Sheet
@@ -30,7 +30,7 @@ class DistributionSheet(Sheet):
             self,
             worksheet: Worksheet,
     ):
-        self.new_distribution_images: List[NewDistributionImage] = []
+        self.distribution_images: List[NewImage] = []
         self.distribution_data: DistributionData = DistributionData()
 
         self.max_col: int = 3
@@ -48,8 +48,8 @@ class DistributionSheet(Sheet):
         for image in worksheet._images:
             file_name: str = f"{uuid.uuid4()}.{image.format}"
 
-            self.new_distribution_images.append(
-                NewDistributionImage(
+            self.distribution_images.append(
+                NewImage(
                     file_name=file_name,
                     file=image.ref,
                 )
